@@ -236,13 +236,16 @@ class Tasks(_Base):
         resp = self.__do_task('PUT', id, operation=self.operation)
         return StopTaskResult(resp)
 
-    def restart_task(self, id):
+    def restart_task(self, id, debug_params=[]):
         """
         usage
              >>> resp = task.restart_task('task_id')
         """
         target = id + '/restart'
-        resp = self.__do_task('PUT', target, operation=self.operation)
+        if self._task_type == 'gwl':
+            raise NotImplementedError("Unsupported restart task type '{}'".format(self._task_type))
+        data = {"debug_params": debug_params}
+        resp = self.__do_task('PUT', target, data=data, operation=self.operation)
         return RestartTaskResult(resp)
 
     def get_jobs(self, id):
